? xml-xerces/java/src/org/w3c/dom/ls/DOMInput.java
? xml-xerces/java/src/org/w3c/dom/ls/DOMOutput.java
? xml-xerces/java/src/org/w3c/dom/ls/DOMParser.java
? xml-xerces/java/src/org/w3c/dom/ls/DOMParserFilter.java
? xml-xerces/java/src/org/w3c/dom/ls/DOMResourceResolver.java
? xml-xerces/java/src/org/w3c/dom/ls/DOMSerializer.java
? xml-xerces/java/src/org/w3c/dom/ls/DOMSerializerFilter.java
Index: xml-xerces/java/src/org/w3c/dom/ls/DocumentLS.java
===================================================================
RCS file: /home/cvspublic/xml-xerces/java/src/org/w3c/dom/ls/DocumentLS.java,v
retrieving revision 1.5
diff -u -w -r1.5 DocumentLS.java
--- xml-xerces/java/src/org/w3c/dom/ls/DocumentLS.java	24 Mar 2003 14:28:45 -0000	1.5
+++ xml-xerces/java/src/org/w3c/dom/ls/DocumentLS.java	29 Jul 2003 12:51:03 -0000
@@ -16,12 +16,6 @@
 import org.w3c.dom.DOMException;
 
 /**
- * DOM Level 3 WD Experimental:
- * The DOM Level 3 specification is at the stage 
- * of Working Draft, which represents work in 
- * progress and thus may be updated, replaced, 
- * or obsoleted by other documents at any time. 
- *
  *  The <code>DocumentLS</code> interface provides a mechanism by which the 
  * content of a document can be serialized, or replaced with the DOM tree 
  * produced when loading a URI, or parsing a string. 
@@ -29,15 +23,14 @@
  * is that an instance of the <code>DocumentLS</code> interface can be 
  * obtained by using binding-specific casting methods on an instance of the 
  * <code>Document</code> interface, or by using the method 
- * <code>Node.getFeature</code> with parameter values <code>"LS-Load"</code> 
- * and <code>"3.0"</code> (respectively) on an <code>Document</code>, if the 
- * <code>Document</code> supports the feature <code>"Core"</code> version 
- * <code>"3.0"</code> defined in [<a href='http://www.w3.org/TR/2002/WD-DOM-Level-3-Core-20021022'>DOM Level 3 Core</a>]
+ * <code>Node.getFeature</code> with parameter values 
+ * <code>"DocumentLS"</code> and <code>"3.0"</code> (respectively) on an 
+ * <code>Document</code>, if the <code>Document</code> supports the feature 
+ * <code>"Core"</code> version <code>"3.0"</code> defined in [<a href='http://www.w3.org/TR/2003/WD-DOM-Level-3-Core-20030609'>DOM Level 3 Core</a>]
  *  
- * <p> This interface is optional. If supported, implementations are must 
- * support version <code>"3.0"</code> of the feature 
- * <code>"LS-DocumentLS"</code>. 
- * <p>See also the <a href='http://www.w3.org/TR/2003/WD-DOM-Level-3-LS-20030226'>Document Object Model (DOM) Level 3 Load
+ * <p> This interface is optional. If supported, implementations must support 
+ * version <code>"3.0"</code> of the feature <code>"DocumentLS"</code>. 
+ * <p>See also the <a href='http://www.w3.org/TR/2003/WD-DOM-Level-3-LS-20030619'>Document Object Model (DOM) Level 3 Load
 and Save Specification</a>.
  */
 public interface DocumentLS {
@@ -46,12 +39,7 @@
      * synchronous or asynchronous. When the async attribute is set to 
      * <code>true</code> the load method returns control to the caller 
      * before the document has completed loading. The default value of this 
-     * attribute is <code>true</code>.  Should the DOM spec define the 
-     * default value of this attribute? What if implementing both async and 
-     * sync IO is impractical in some systems?  2001-09-14. default is 
-     * <code>false</code> but we need to check with Mozilla and IE.  
-     * 2003-01-24. Checked with IE and Mozilla, default is <code>true</code>
-     * . 
+     * attribute is <code>true</code>. 
      */
     public boolean getAsync();
     /**
@@ -59,12 +47,7 @@
      * synchronous or asynchronous. When the async attribute is set to 
      * <code>true</code> the load method returns control to the caller 
      * before the document has completed loading. The default value of this 
-     * attribute is <code>true</code>.  Should the DOM spec define the 
-     * default value of this attribute? What if implementing both async and 
-     * sync IO is impractical in some systems?  2001-09-14. default is 
-     * <code>false</code> but we need to check with Mozilla and IE.  
-     * 2003-01-24. Checked with IE and Mozilla, default is <code>true</code>
-     * . 
+     * attribute is <code>true</code>. 
      * @exception DOMException
      *   NOT_SUPPORTED_ERR: Raised if the implementation doesn't support the 
      *   mode the attribute is being set to.
@@ -84,25 +67,34 @@
      * Replaces the content of the document with the result of parsing the 
      * given URI. Invoking this method will either block the caller or 
      * return to the caller immediately depending on the value of the async 
-     * attribute. Once the document is fully loaded the document will fire a 
-     * "load" event that the caller can register as a listener for. If an 
-     * error occurs the document will fire an "error" event so that the 
-     * caller knows that the load failed (see <code>ParseErrorEvent</code>). 
-     * If this method is called on a document that is currently loading, the 
-     * current load is interrupted and the new URI load is initiated.
-     * <br>When invoking this method the features used in the 
-     * <code>DOMBuilder</code> interface are assumed to have their default 
-     * values with the exception that the feature "entities" is "false".
+     * attribute. Once the document is fully loaded a "load" event (as 
+     * defined in [<a href='http://www.w3.org/TR/2003/WD-DOM-Level-3-Events-20030331'>DOM Level 3 Events</a>]
+     * , except that the <code>Event.targetNode</code> will be the document, 
+     * not an element) will be dispatched on the document. If an error 
+     * occurs, an implementation dependent "error" event will be dispatched 
+     * on the document. If this method is called on a document that is 
+     * currently loading, the current load is interrupted and the new URI 
+     * load is initiated. 
+     * <br> When invoking this method the parameters used in the 
+     * <code>DOMParser</code> interface are assumed to have their default 
+     * values with the exception that the parameters <code>"entities"</code>
+     * , <code>"normalize-characters"</code>, 
+     * <code>"check-character-normalization"</code> are set to 
+     * <code>"false"</code>. 
+     * <br> The result of a call to this method is the same the result of a 
+     * call to <code>DOMParser.parseWithContext</code> with an input stream 
+     * referencing the URI that was passed to this call, the document as the 
+     * context node, and the action <code>ACTION_REPLACE_CHILDREN</code>. 
      * @param uri The URI reference for the XML file to be loaded. If this is 
      *   a relative URI, the base URI used by the implementation is 
      *   implementation dependent.
      * @return If async is set to <code>true</code> <code>load</code> returns 
      *   <code>true</code> if the document load was successfully initiated. 
-     *   If an error occurred when initiating the document load 
+     *   If an error occurred when initiating the document load, 
      *   <code>load</code> returns <code>false</code>.If async is set to 
      *   <code>false</code> <code>load</code> returns <code>true</code> if 
      *   the document was successfully loaded and parsed. If an error 
-     *   occurred when either loading or parsing the URI <code>load</code> 
+     *   occurred when either loading or parsing the URI, <code>load</code> 
      *   returns <code>false</code>.
      */
     public boolean load(String uri);
@@ -110,10 +102,14 @@
     /**
      *  Replace the content of the document with the result of parsing the 
      * input string, this method is always synchronous. This method always 
-     * parses from a DOMString, which means the data is always UTF16. All 
+     * parses from a DOMString, which means the data is always UTF-16. All 
      * other encoding information is ignored. 
-     * <br>The features used in the <code>DOMBuilder</code> interface are 
+     * <br> The parameters used in the <code>DOMParser</code> interface are 
      * assumed to have their default values when invoking this method.
+     * <br> The result of a call to this method is the same the result of a 
+     * call to <code>DOMParser.parseWithContext</code> with an input stream 
+     * containing the string passed to this call, the document as the 
+     * context node, and the action <code>ACTION_REPLACE_CHILDREN</code>. 
      * @param source A string containing an XML document.
      * @return <code>true</code> if parsing the input string succeeded 
      *   without errors, otherwise <code>false</code>.
@@ -123,18 +119,21 @@
     /**
      * Save the document or the given node and all its descendants to a string 
      * (i.e. serialize the document or node). 
-     * <br>The features used in the <code>DOMWriter</code> interface are 
+     * <br>The parameters used in the <code>DOMSerializer</code> interface are 
      * assumed to have their default values when invoking this method. 
-     * @param snode Specifies what to serialize, if this parameter is 
+     * <br> The result of a call to this method is the same the result of a 
+     * call to <code>DOMSerializer.writeToString</code> with the document as 
+     * the node to write. 
+     * @param node Specifies what to serialize, if this parameter is 
      *   <code>null</code> the whole document is serialized, if it's 
      *   non-null the given node is serialized.
      * @return The serialized document or <code>null</code> in case an error 
-     *   occured.
+     *   occurred.
      * @exception DOMException
      *   WRONG_DOCUMENT_ERR: Raised if the node passed in as the node 
      *   parameter is from an other document.
      */
-    public String saveXML(Node snode)
+    public String saveXML(Node node)
                           throws DOMException;
 
 }
Index: xml-xerces/java/src/org/w3c/dom/ls/ElementLS.java
===================================================================
RCS file: /home/cvspublic/xml-xerces/java/src/org/w3c/dom/ls/ElementLS.java,v
retrieving revision 1.1
diff -u -w -r1.1 ElementLS.java
--- xml-xerces/java/src/org/w3c/dom/ls/ElementLS.java	24 Mar 2003 14:28:45 -0000	1.1
+++ xml-xerces/java/src/org/w3c/dom/ls/ElementLS.java	29 Jul 2003 12:51:03 -0000
@@ -13,12 +13,6 @@
 package org.w3c.dom.ls;
 
 /**
- * DOM Level 3 WD Experimental:
- * The DOM Level 3 specification is at the stage 
- * of Working Draft, which represents work in 
- * progress and thus may be updated, replaced, 
- * or obsoleted by other documents at any time. 
- *
  *  The <code>ElementLS</code> interface provides a convenient mechanism by 
  * which the children of an element can be serialized to a string, or 
  * replaced by the result of parsing a provided string. 
@@ -26,14 +20,14 @@
  * is that an instance of the <code>ElementLS</code> interface can be 
  * obtained by using binding-specific casting methods on an instance of the 
  * <code>Element</code> interface, or by using the method 
- * <code>Node.getFeature</code> with parameter values <code>"LS-Load"</code> 
- * and <code>"3.0"</code> (respectively) on an <code>Element</code>, if the 
- * <code>Element</code> supports the feature <code>"Core"</code> version 
- * <code>"3.0"</code> defined in [<a href='http://www.w3.org/TR/2002/WD-DOM-Level-3-Core-20021022'>DOM Level 3 Core</a>]
+ * <code>Node.getFeature</code> with parameter values 
+ * <code>"ElementLS"</code> and <code>"3.0"</code> (respectively) on an 
+ * <code>Element</code>, if the <code>Element</code> supports the feature 
+ * <code>"Core"</code> version <code>"3.0"</code> defined in [<a href='http://www.w3.org/TR/2003/WD-DOM-Level-3-Core-20030609'>DOM Level 3 Core</a>]
  * . 
  * <p> This interface is optional. If supported, implementations must support 
- * version <code>"3.0"</code> of the feature <code>"LS-ElementLS"</code>. 
- * <p>See also the <a href='http://www.w3.org/TR/2003/WD-DOM-Level-3-LS-20030226'>Document Object Model (DOM) Level 3 Load
+ * version <code>"3.0"</code> of the feature <code>"ElementLS"</code>. 
+ * <p>See also the <a href='http://www.w3.org/TR/2003/WD-DOM-Level-3-LS-20030619'>Document Object Model (DOM) Level 3 Load
 and Save Specification</a>.
  */
 public interface ElementLS {
@@ -41,46 +35,46 @@
      *  The content of the element in serialized form. 
      * <br> When getting the value of this attribute, the children are 
      * serialized in document order and the serialized result is returned. 
-     * This is equivalent of calling <code>DOMWriter.writeToString()</code> 
-     * on all children in document order and appending the result of the 
-     * individual results to a single string that is then returned as the 
-     * value of this attribute. 
+     * This is equivalent of calling 
+     * <code>DOMSerializer.writeToString()</code> on all children in 
+     * document order and appending the result of the individual results to 
+     * a single string that is then returned as the value of this attribute. 
      * <br> When setting the value of this attribute, all children of the 
      * element are removed, the provided string is parsed and the result of 
      * the parse operation is inserted into the element. This is equivalent 
-     * of calling <code>DOMBuilder.parseWithContext()</code> passing in the 
+     * of calling <code>DOMParser.parseWithContext()</code> passing in the 
      * provided string (through the input source argument), the 
      * <code>Element</code>, and the action 
-     * <code>ACTION_REPLACE_CHILDREN</code>. If an error occures while 
+     * <code>ACTION_REPLACE_CHILDREN</code>. If an error occurs while 
      * parsing the provided string, the <code>Element</code>'s owner 
      * document's error handler will be called, and the <code>Element</code> 
      * is left with no children. 
      * <br> Both setting and getting the value of this attribute assumes that 
-     * the parameters in the DOMConfiguration object have their default 
-     * values. 
+     * the parameters in the <code>DOMConfiguration</code> object have their 
+     * default values. 
      */
     public String getMarkupContent();
     /**
      *  The content of the element in serialized form. 
      * <br> When getting the value of this attribute, the children are 
      * serialized in document order and the serialized result is returned. 
-     * This is equivalent of calling <code>DOMWriter.writeToString()</code> 
-     * on all children in document order and appending the result of the 
-     * individual results to a single string that is then returned as the 
-     * value of this attribute. 
+     * This is equivalent of calling 
+     * <code>DOMSerializer.writeToString()</code> on all children in 
+     * document order and appending the result of the individual results to 
+     * a single string that is then returned as the value of this attribute. 
      * <br> When setting the value of this attribute, all children of the 
      * element are removed, the provided string is parsed and the result of 
      * the parse operation is inserted into the element. This is equivalent 
-     * of calling <code>DOMBuilder.parseWithContext()</code> passing in the 
+     * of calling <code>DOMParser.parseWithContext()</code> passing in the 
      * provided string (through the input source argument), the 
      * <code>Element</code>, and the action 
-     * <code>ACTION_REPLACE_CHILDREN</code>. If an error occures while 
+     * <code>ACTION_REPLACE_CHILDREN</code>. If an error occurs while 
      * parsing the provided string, the <code>Element</code>'s owner 
      * document's error handler will be called, and the <code>Element</code> 
      * is left with no children. 
      * <br> Both setting and getting the value of this attribute assumes that 
-     * the parameters in the DOMConfiguration object have their default 
-     * values. 
+     * the parameters in the <code>DOMConfiguration</code> object have their 
+     * default values. 
      */
     public void setMarkupContent(String markupContent);
 
Index: xml-xerces/java/src/org/w3c/dom/ls/LSLoadEvent.java
===================================================================
RCS file: /home/cvspublic/xml-xerces/java/src/org/w3c/dom/ls/LSLoadEvent.java,v
retrieving revision 1.5
diff -u -w -r1.5 LSLoadEvent.java
--- xml-xerces/java/src/org/w3c/dom/ls/LSLoadEvent.java	24 Mar 2003 14:28:45 -0000	1.5
+++ xml-xerces/java/src/org/w3c/dom/ls/LSLoadEvent.java	29 Jul 2003 12:51:03 -0000
@@ -16,15 +16,9 @@
 import org.w3c.dom.events.Event;
 
 /**
- * DOM Level 3 WD Experimental:
- * The DOM Level 3 specification is at the stage 
- * of Working Draft, which represents work in 
- * progress and thus may be updated, replaced, 
- * or obsoleted by other documents at any time. 
- *
  *  This interface represents a load event object that signals the completion 
  * of a document load. 
- * <p>See also the <a href='http://www.w3.org/TR/2003/WD-DOM-Level-3-LS-20030226'>Document Object Model (DOM) Level 3 Load
+ * <p>See also the <a href='http://www.w3.org/TR/2003/WD-DOM-Level-3-LS-20030619'>Document Object Model (DOM) Level 3 Load
 and Save Specification</a>.
  */
 public interface LSLoadEvent extends Event {
@@ -36,6 +30,6 @@
     /**
      * The input source that was parsed.
      */
-    public DOMInputSource getInputSource();
+    public DOMInput getInput();
 
 }
Index: xml-xerces/java/src/org/w3c/dom/ls/LSProgressEvent.java
===================================================================
RCS file: /home/cvspublic/xml-xerces/java/src/org/w3c/dom/ls/LSProgressEvent.java,v
retrieving revision 1.5
diff -u -w -r1.5 LSProgressEvent.java
--- xml-xerces/java/src/org/w3c/dom/ls/LSProgressEvent.java	24 Mar 2003 14:28:45 -0000	1.5
+++ xml-xerces/java/src/org/w3c/dom/ls/LSProgressEvent.java	29 Jul 2003 12:51:03 -0000
@@ -15,29 +15,18 @@
 import org.w3c.dom.events.Event;
 
 /**
- * DOM Level 3 WD Experimental:
- * The DOM Level 3 specification is at the stage 
- * of Working Draft, which represents work in 
- * progress and thus may be updated, replaced, 
- * or obsoleted by other documents at any time. 
- *
- * DOM Level 3 WD Experimental:
- * The DOM Level 3 specification is at the stage 
- * of Working Draft, which represents work in 
- * progress and thus may be updated, replaced, 
- * or obsoleted by other documents at any time. 
- *
  *  This interface represents a progress event object that notifies the 
  * application about progress as a document is parsed. It extends the 
- * <code>Event</code> interface defined in [<a href='http://www.w3.org/TR/DOM-Level-3-Events'>DOM Level 3 Events</a>].
- * <p>See also the <a href='http://www.w3.org/TR/2003/WD-DOM-Level-3-LS-20030226'>Document Object Model (DOM) Level 3 Load
+ * <code>Event</code> interface defined in [<a href='http://www.w3.org/TR/2003/WD-DOM-Level-3-Events-20030331'>DOM Level 3 Events</a>]
+ * .
+ * <p>See also the <a href='http://www.w3.org/TR/2003/WD-DOM-Level-3-LS-20030619'>Document Object Model (DOM) Level 3 Load
 and Save Specification</a>.
  */
 public interface LSProgressEvent extends Event {
     /**
      * The input source that is being parsed.
      */
-    public DOMInputSource getInputSource();
+    public DOMInput getInput();
 
     /**
      * The current position in the input source, including all external 

Index: xml-xerces/java/src/org/w3c/dom/ls/DOMImplementationLS.java
===================================================================
RCS file: /home/cvspublic/xml-xerces/java/src/org/w3c/dom/ls/DOMImplementationLS.java,v
retrieving revision 1.5
diff -u -w -r1.5 DOMImplementationLS.java
--- xml-xerces/java/src/org/w3c/dom/ls/DOMImplementationLS.java	24 Mar 2003 14:28:45 -0000	1.5
+++ xml-xerces/java/src/org/w3c/dom/ls/DOMImplementationLS.java	29 Jul 2003 12:51:03 -0000
@@ -15,56 +15,49 @@
 import org.w3c.dom.DOMException;
 
 /**
- * DOM Level 3 WD Experimental:
- * The DOM Level 3 specification is at the stage 
- * of Working Draft, which represents work in 
- * progress and thus may be updated, replaced, 
- * or obsoleted by other documents at any time. 
- *
  *  <code>DOMImplementationLS</code> contains the factory methods for creating 
- * objects that implement the <code>DOMBuilder</code> (parser) and 
- * <code>DOMWriter</code> (serializer) interfaces. 
+ * Load and Save objects.
  * <p> The expectation is that an instance of the 
  * <code>DOMImplementationLS</code> interface can be obtained by using 
  * binding-specific casting methods on an instance of the 
  * <code>DOMImplementation</code> interface or, if the <code>Document</code> 
  * supports the feature <code>"Core"</code> version <code>"3.0"</code> 
- * defined in [<a href='http://www.w3.org/TR/2002/WD-DOM-Level-3-Core-20021022'>DOM Level 3 Core</a>]
+ * defined in [<a href='http://www.w3.org/TR/2003/WD-DOM-Level-3-Core-20030609'>DOM Level 3 Core</a>]
  * , by using the method <code>DOMImplementation.getFeature</code> with 
- * parameter values <code>"LS-Load"</code> and <code>"3.0"</code> 
- * (respectively). 
- * <p>See also the <a href='http://www.w3.org/TR/2003/WD-DOM-Level-3-LS-20030226'>Document Object Model (DOM) Level 3 Load
+ * parameter values <code>"LS"</code> (or <code>"LS-Async"</code>) and
+ * <code>"3.0"</code> (respectively).
+ * <p>See also the <a href='http://www.w3.org/TR/2003/WD-DOM-Level-3-LS-20030619'>Document Object Model (DOM) Level 3 Load
 and Save Specification</a>.
  */
 public interface DOMImplementationLS {
-    // DOMIMplementationLSMode
+    // DOMImplementationLSMode
     /**
-     * Create a synchronous <code>DOMBuilder</code>.
+     * Create a synchronous <code>DOMParser</code>.
      */
     public static final short MODE_SYNCHRONOUS          = 1;
     /**
      * Create an asynchronous <code>DOMBuilder</code>.
      */
     public static final short MODE_ASYNCHRONOUS         = 2;
 
     /**
      * Create a new <code>DOMBuilder</code>. The newly constructed parser may 
      * then be configured by means of its <code>setFeature</code> method, 
      * and used to parse documents by means of its <code>parse</code> 
      * method. 
      * @param mode  The <code>mode</code> argument is either 
      *   <code>MODE_SYNCHRONOUS</code> or <code>MODE_ASYNCHRONOUS</code>, if 
      *   <code>mode</code> is <code>MODE_SYNCHRONOUS</code> then the 
      *   <code>DOMBuilder</code> that is created will operate in synchronous 
      *   mode, if it's <code>MODE_ASYNCHRONOUS</code> then the 
      *   <code>DOMBuilder</code> that is created will operate in 
      *   asynchronous mode. 
      * @param schemaType  An absolute URI representing the type of the schema 
      *   language used during the load of a <code>Document</code> using the 
      *   newly created <code>DOMBuilder</code>. Note that no lexical 
      *   checking is done on the absolute URI. In order to create a 
      *   <code>DOMBuilder</code> for any kind of schema types (i.e. the 
      *   DOMBuilder will be free to use any schema found), use the value 
      *   <code>null</code>. 
      * <p ><b>Note:</b>    For W3C XML Schema [<a href='http://www.w3.org/TR/2001/REC-xmlschema-1-20010502/'>XML Schema Part 1</a>]
      *   , applications must use the value 
@@ -73,45 +66,43 @@
      *   <code>"http://www.w3.org/TR/REC-xml"</code>. Other Schema languages 
      *   are outside the scope of the W3C and therefore should recommend an 
      *   absolute URI in order to use this method. 
      * @return  The newly created <code>DOMBuilder</code> object. This 
      *   <code>DOMBuilder</code> is either synchronous or asynchronous 
      *   depending on the value of the <code>mode</code> argument. 
      * <p ><b>Note:</b>    By default, the newly created 
      *   <code>DOMBuilder</code> does not contain a 
      *   <code>DOMErrorHandler</code>, i.e. the value of the 
      *   <code>errorHandler</code> is <code>null</code>. However, 
      *   implementations may provide a default error handler at creation 
      *   time. In that case, the initial value of the 
      *   <code>errorHandler</code> attribute on the new created 
      *   <code>DOMBuilder</code> contains a reference to the default error 
      *   handler. 
      * @exception DOMException
      *    NOT_SUPPORTED_ERR: Raised if the requested mode or schema type is 
      *   not supported. 
      */
-    public DOMBuilder createDOMBuilder(short mode, 
+    public DOMParser createDOMParser(short mode,
                                        String schemaType)
                                        throws DOMException;
 
     /**
      * Create a new <code>DOMWriter</code> object. <code>DOMWriter</code>s are 
      * used to serialize a DOM tree back into an XML document. 
      * @return The newly created <code>DOMWriter</code> object.
      * <p ><b>Note:</b>    By default, the newly created <code>DOMWriter</code>
      *    does not contain a <code>DOMErrorHandler</code>, i.e. the value of 
      *   the <code>errorHandler</code> is <code>null</code>. However, 
      *   implementations may provide a default error handler at creation 
      *   time. In that case, the initial value of the 
      *   <code>errorHandler</code> attribute on the new created 
      *   <code>DOMWriter</code> contains a reference to the default error 
      *   handler. 
      */
-    public DOMWriter createDOMWriter();
+    public DOMSerializer createDOMSerializer();
 
-    /**
-     *  Create a new "empty" <code>DOMInputSource</code>. 
-     * @return  The newly created <code>DOMInputSource</code> object. 
+    /*
+     * Create a new empty input source.
+     * @return  The newly created input object.
      */
-    public DOMInputSource createDOMInputSource();
+    public DOMInput createDOMInput();
 
 }
@@ -15,56 +15,49 @@
     public static final short MODE_SYNCHRONOUS          = 1;
     /**
-     * Create an asynchronous <code>DOMBuilder</code>.
+     * Create an asynchronous <code>DOMParser</code>.
      */
     public static final short MODE_ASYNCHRONOUS         = 2;
@@ -15,56 +15,49 @@
 
     /**
-     * Create a new <code>DOMBuilder</code>. The newly constructed parser may 
-     * then be configured by means of its <code>setFeature</code> method, 
-     * and used to parse documents by means of its <code>parse</code> 
+     * Create a new <code>DOMParser</code>. The newly constructed parser may
+     * then be configured by means of its <code>DOMConfiguration</code>
+     * object, and used to parse documents by means of its <code>parse</code>
      * method. 
      * @param mode  The <code>mode</code> argument is either 
@@ -15,56 +15,49 @@
      *   <code>MODE_SYNCHRONOUS</code> or <code>MODE_ASYNCHRONOUS</code>, if 
      *   <code>mode</code> is <code>MODE_SYNCHRONOUS</code> then the 
-     *   <code>DOMBuilder</code> that is created will operate in synchronous 
+     *   <code>DOMParser</code> that is created will operate in synchronous
      *   mode, if it's <code>MODE_ASYNCHRONOUS</code> then the 
@@ -15,56 +15,49 @@
      *   mode, if it's <code>MODE_ASYNCHRONOUS</code> then the 
-     *   <code>DOMBuilder</code> that is created will operate in 
-     *   asynchronous mode. 
+     *   <code>DOMParser</code> that is created will operate in asynchronous
+     *   mode.
      * @param schemaType  An absolute URI representing the type of the schema 
      *   language used during the load of a <code>Document</code> using the 
@@ -15,56 +15,49 @@
      * @param schemaType  An absolute URI representing the type of the schema 
      *   language used during the load of a <code>Document</code> using the 
-     *   newly created <code>DOMBuilder</code>. Note that no lexical 
-     *   checking is done on the absolute URI. In order to create a 
-     *   <code>DOMBuilder</code> for any kind of schema types (i.e. the 
-     *   DOMBuilder will be free to use any schema found), use the value 
+     *   newly created <code>DOMParser</code>. Note that no lexical checking
+     *   is done on the absolute URI. In order to create a
+     *   <code>DOMParser</code> for any kind of schema types (i.e. the
+     *   DOMParser will be free to use any schema found), use the value
      *   <code>null</code>. 
      * <p ><b>Note:</b>    For W3C XML Schema [<a href='http://www.w3.org/TR/2001/REC-xmlschema-1-20010502/'>XML Schema Part 1</a>]
@@ -73,45 +66,43 @@
      *   are outside the scope of the W3C and therefore should recommend an 
      *   absolute URI in order to use this method. 
-     * @return  The newly created <code>DOMBuilder</code> object. This 
-     *   <code>DOMBuilder</code> is either synchronous or asynchronous 
+     * @return  The newly created <code>DOMParser</code> object. This
+     *   <code>DOMParser</code> is either synchronous or asynchronous
      *   depending on the value of the <code>mode</code> argument. 
@@ -73,45 +66,43 @@
      *   depending on the value of the <code>mode</code> argument. 
-     * <p ><b>Note:</b>    By default, the newly created 
-     *   <code>DOMBuilder</code> does not contain a 
-     *   <code>DOMErrorHandler</code>, i.e. the value of the 
-     *   <code>errorHandler</code> is <code>null</code>. However, 
-     *   implementations may provide a default error handler at creation 
-     *   time. In that case, the initial value of the 
-     *   <code>errorHandler</code> attribute on the new created 
-     *   <code>DOMBuilder</code> contains a reference to the default error 
-     *   handler. 
+     * <p ><b>Note:</b>    By default, the newly created <code>DOMParser</code>
+     *    does not contain a <code>DOMErrorHandler</code>, i.e. the value of
+     *   the "<a href='http://www.w3.org/TR/2003/WD-DOM-Level-3-Core-20030609/core.html#parameter-error-handler'>
+     *   error-handler</a>" configuration parameter is <code>null</code>. However, implementations
+     *   may provide a default error handler at creation time. In that case,
+     *   the initial value of the <code>"error-handler"</code> configuration
+     *   parameter on the new created <code>DOMParser</code> contains a
+     *   reference to the default error handler.
      * @exception DOMException
      *    NOT_SUPPORTED_ERR: Raised if the requested mode or schema type is 
@@ -73,45 +66,43 @@
 
     /**
-     * Create a new <code>DOMWriter</code> object. <code>DOMWriter</code>s are 
-     * used to serialize a DOM tree back into an XML document. 
-     * @return The newly created <code>DOMWriter</code> object.
-     * <p ><b>Note:</b>    By default, the newly created <code>DOMWriter</code>
-     *    does not contain a <code>DOMErrorHandler</code>, i.e. the value of 
-     *   the <code>errorHandler</code> is <code>null</code>. However, 
-     *   implementations may provide a default error handler at creation 
-     *   time. In that case, the initial value of the 
-     *   <code>errorHandler</code> attribute on the new created 
-     *   <code>DOMWriter</code> contains a reference to the default error 
-     *   handler. 
+     *  Create a new <code>DOMSerializer</code> object.
+     * @return The newly created <code>DOMSerializer</code> object.
+     * <p ><b>Note:</b>    By default, the newly created
+     *   <code>DOMSerializer</code> has no <code>DOMErrorHandler</code>,
+     *   i.e. the value of the <code>"error-handler"</code> configuration
+     *   parameter is <code>null</code>. However, implementations may
+     *   provide a default error handler at creation time. In that case, the
+     *   initial value of the <code>"error-handler"</code> configuration
+     *   parameter on the new created <code>DOMSerializer</code> contains a
+     *   reference to the default error handler.
      */